@@ -15,13 +15,13 @@ const ABOUT_PATH: &str = "/about.html";
 const EXPECT_WORKERS: usize = 2;
 
 // Test task.
-pub async fn get_index(user: &GooseUser) -> GooseTaskResult {
+pub async fn get_index(user: &mut GooseUser) -> GooseTaskResult {
     let _goose = user.get(INDEX_PATH).await?;
     Ok(())
 }
 
 // Test task.
-pub async fn get_about(user: &GooseUser) -> GooseTaskResult {
+pub async fn get_about(user: &mut GooseUser) -> GooseTaskResult {
     let _goose = user.get(ABOUT_PATH).await?;
     Ok(())
 }
@@ -216,7 +216,7 @@ fn validate_closer_test(
 
 // Helper to run the test, takes a flag for indicating if running in standalone
 // mode or Gaggle mode.
-fn run_load_test(is_gaggle: bool) {
+async fn run_load_test(is_gaggle: bool) {
     // Start mock server.
     let server = MockServer::start();
 
@@ -236,7 +236,8 @@ fn run_load_test(is_gaggle: bool) {
             let goose_metrics = common::run_load_test(
                 common::build_load_test(configuration.clone(), &build_taskset(), None, None),
                 None,
-            );
+            )
+            .await;
 
             (configuration, goose_metrics)
         }
@@ -246,10 +247,9 @@ fn run_load_test(is_gaggle: bool) {
                 common_build_configuration(&server, test_endpoints.len(), Some(true), None);
 
             // Workers launched in own threads, store thread handles.
-            let worker_handles = common::launch_gaggle_workers(
-                common::build_load_test(worker_configuration, &build_taskset(), None, None),
-                EXPECT_WORKERS,
-            );
+            let worker_handles = common::launch_gaggle_workers(EXPECT_WORKERS, || {
+                common::build_load_test(worker_configuration.clone(), &build_taskset(), None, None)
+            });
 
             // Build Manager configuration.
             let manager_configuration = common_build_configuration(
@@ -268,7 +268,8 @@ fn run_load_test(is_gaggle: bool) {
                     None,
                 ),
                 Some(worker_handles),
-            );
+            )
+            .await;
 
             (manager_configuration, goose_metrics)
         }
@@ -278,20 +279,20 @@ fn run_load_test(is_gaggle: bool) {
     validate_closer_test(&mock_endpoints, &goose_metrics, &configuration);
 }
 
-#[test]
+#[tokio::test]
 // Load test with a single task set containing two weighted tasks setup via closure.
 // Validate weighting and statistics.
-fn test_single_taskset_closure() {
+async fn test_single_taskset_closure() {
     // Run load test with is_gaggle set to false.
-    run_load_test(false);
+    run_load_test(false).await;
 }
 
-#[test]
+#[tokio::test(flavor = "multi_thread", worker_threads = 8)]
 #[cfg_attr(not(feature = "gaggle"), ignore)]
 // Spawn a gaggle of 1 manager and 2 workers each simulating one user. Run a load test,
 // with a single task set containing two weighted tasks setup via closure. Validate
 // that weighting and metrics are correctly merged to the Manager.
-fn test_single_taskset_closure_gaggle() {
+async fn test_single_taskset_closure_gaggle() {
     // Run load test with is_gaggle set to true.
-    run_load_test(true);
+    run_load_test(true).await;
 }
